Coverage for src\zapy\api\models.py: 100%

1 from pydantic import BaseModel

2

3

4 class ServerConnection(BaseModel):

5 host: str

6 port: int

7

8

9

10 from uvicorn.main import *

11 from typing_extensions import TypedDict

12

13 class UvicornRunConfig(TypedDict):

14 host: str

15 port: int

16 uds: typing.Optional[str]

17 fd: typing.Optional[int]

18 loop: LoopSetupType

19 http: typing.Union[typing.Type[asyncio.Protocol], HTTPProtocolType]

20 ws: typing.Union[typing.Type[asyncio.Protocol], WSProtocolType]

21 ws_max_size: int

22 ws_max_queue: int

23 ws_ping_interval: typing.Optional[float]

24 ws_ping_timeout: typing.Optional[float]

25 ws_per_message_deflate: bool

26 lifespan: LifespanType

27 interface: InterfaceType

28 reload: bool

29 reload_dirs: typing.Optional[typing.Union[typing.List[str], str]]

30 reload_includes: typing.Optional[typing.Union[typing.List[str], str]]

31 reload_excludes: typing.Optional[typing.Union[typing.List[str], str]]

32 reload_delay: float

33 workers: typing.Optional[int]

34 env_file: typing.Optional[typing.Union[str, os.PathLike]]

35 log_config: typing.Optional[

36 typing.Union[typing.Dict[str, typing.Any], str]

37 ]

38 log_level: typing.Optional[typing.Union[str, int]]

39 access_log: bool

40 proxy_headers: bool

41 server_header: bool

42 date_header: bool

43 forwarded_allow_ips: typing.Optional[typing.Union[typing.List[str], str]]

44 root_path: str

45 limit_concurrency: typing.Optional[int]

46 backlog: int

47 limit_max_requests: typing.Optional[int]

48 timeout_keep_alive: int

49 timeout_graceful_shutdown: typing.Optional[int]

50 ssl_keyfile: typing.Optional[str]

51 ssl_certfile: typing.Optional[typing.Union[str, os.PathLike]]

52 ssl_keyfile_password: typing.Optional[str]

53 ssl_version: int

54 ssl_cert_reqs: int

55 ssl_ca_certs: typing.Optional[str]

56 ssl_ciphers: str

57 headers: typing.Optional[typing.List[typing.Tuple[str, str]]]

58 use_colors: typing.Optional[bool]

59 app_dir: typing.Optional[str]

60 factory: bool

61 h11_max_incomplete_event_size: typing.Optional[int]